De mest almindelige knapper

De mest almindelige knapper | TOC

Herunder finder du en beskrivelse af de enkelte knapper.

| Fed tekst (Ctrl+B).
| Kursiv (Ctrl+I).
| Understregning (Ctrl+U).
| Gennemstregning.
| Juster til venstre.
| Centrer.
| Juster til højre.
| Lige højre margen.
| Punktopstillet liste.
| Nummeret liste
| Flyt tekst til venstre.
| Flyt tekst til højre.
| Fortryd sidste valg (Ctrl+Z).
| Gentag sidste valg (Ctrl+Y).
| Indsæt nyt link - læs mere om denne funktion i afsnittet Indsættelse af link.
| Fjern aktuelt valgte link(s).
| Indsæt nyt bogmærke - læs mere om denne funktion i afsnittet om Bogmærker.
| Indsæt nyt billede - læs mere om denne funktion i afsnittet om Billedbehandling.
| Ryd op i koden / fjern uønsket formatering. Denne funktion er brugbar, når man indsætter tekst f. eks. fra et office-produkt.
| Viser dette hjælpevindue.
| Åbner editoren til redigering af HTML-kode.
| Indsætter en ny tabel, hvor cursoren aktuelt er anbragt.
| Tilføjer en række over den aktuelle.
| Tilføjer en række under den aktuelle.
| Fjerner en række.
| Tilføjer en kolonne før den aktuelle.
| Tilføjer en kolonne efter den aktuelle.
| Fjerner den aktuelle kolonne.
| Indsætter en vandret streg.
| Fjerner al formatering fra den aktuelt valgte tekst.
| Sætter det valgte som sænket skrift.
| Sætter det valgte som hævet skrift.

Tilbage til: Indholdsfortegnelse | Top